@@ -1,28 +1,12 @@
 package Facebook::Graph::Publish::Post;
 BEGIN {
-  $Facebook::Graph::Publish::Post::VERSION = '0.0500';
+  $Facebook::Graph::Publish::Post::VERSION = '0.0600';
 }
 
 use Any::Moose;
-use Facebook::Graph::Response;
-with 'Facebook::Graph::Role::Uri';
-use LWP::UserAgent;
+extends 'Facebook::Graph::Publish';
 
-has secret => (
-    is          => 'ro',
-    required    => 0,
-    predicate   => 'has_secret',
-);
-
-has access_token => (
-    is          => 'ro',
-    predicate   => 'has_access_token',
-);
-
-has object_name => (
-    is          => 'rw',
-    default     => 'me',
-);
+use constant object_path => '/feed';
 
 has message => (
     is          => 'rw',
@@ -35,7 +19,6 @@ sub set_message {
     return $self;
 }
 
-
 has picture_uri => (
     is          => 'rw',
     predicate   => 'has_picture_uri',
@@ -95,47 +78,30 @@ sub set_link_description {
     return $self;
 }
 
-
-
-sub to {
-    my ($self, $object_name) = @_;
-    $self->object_name($object_name);
-    return $self;
-}
-
-sub publish {
-    my ($self) = @_;
-    my %post;
-    if ($self->has_access_token) {
-        $post{access_token} = $self->access_token;
-    }
+around get_post_params => sub {
+    my ($orig, $self) = @_;
+    my $post = $orig->($self);
     if ($self->has_message) {
-        $post{message} = $self->message;
+        $post->{message} = $self->message;
     }
     if ($self->has_link_uri) {
-        $post{link} = $self->link_uri;
+        $post->{link} = $self->link_uri;
     }
     if ($self->has_link_name) {
-        $post{name} = $self->link_name;
+        $post->{name} = $self->link_name;
     }
     if ($self->has_link_caption) {
-        $post{caption} = $self->link_caption;
+        $post->{caption} = $self->link_caption;
     }
     if ($self->has_link_description) {
-        $post{description} = $self->link_description;
+        $post->{description} = $self->link_description;
     }
     if ($self->has_picture_uri) {
-        $post{picture} = $self->picture_uri;
+        $post->{picture} = $self->picture_uri;
     }
-    my $uri = $self->uri;
-    $uri->path($self->object_name.'/feed');
-    my $response = LWP::UserAgent->new->post($uri, \%post);
-    my %params = (response => $response);
-    if ($self->has_secret) {
-        $params{secret} = $self->secret;
-    }
-    return Facebook::Graph::Response->new(%params);
-}
+    return $post;
+};
+
 
 no Any::Moose;
 __PACKAGE__->meta->make_immutable;
@@ -147,17 +113,17 @@ Facebook::Graph::Publish::Post - Publish to a user's wall.
 
 =head1 VERSION
 
-version 0.0500
+version 0.0600
 
 =head1 SYNOPSIS
 
  my $fb = Facebook::Graph->new;
 
- $fb->publish_post
+ $fb->add_post
     ->set_message('I like beer.')
     ->publish;
 
- my $response = $fb->publish_post
+ my $response = $fb->add_post
     ->set_message('I like Perl.')
     ->set_picture_uri('http://www.perl.org/i/camel_head.png')
     ->set_link_uri('http://www.perl.org/')
@@ -171,7 +137,9 @@ version 0.0500
 
 This module gives you quick and easy access to publish to a user's Facebook feed.
 
-B<NOTE:> Facebook seems to use these terms interchangibly: Feed, Post, Link, News, Wall. So if you want to publish to a user's wall, this is the mechanism you use to do that.
+B<ATTENTION:> You must have the C<publish_stream> privilege to use this module.
+
+B<TIP:> Facebook seems to use these terms interchangibly: Feed, Post, News, Wall. So if you want to publish to a user's wall, this is the mechanism you use to do that.
 
 =head1 METHODS
 
@@ -238,7 +206,7 @@ A text string.
 
 =head2 publish ( )
 
-Posts the data and returns a L<Facebook::Graph::Response> object. The response object should contain the id of the message:
+Posts the data and returns a L<Facebook::Graph::Response> object. The response object should contain the id:
 
  {"id":"1647395831_130068550371568"}
 
